[![Documentation Status](https://readthedocs.org/projects/pytest_info_collector/badge/?version=latest)](http://pytest_info_collector.readthedocs.org/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/aragilar/pytest_info_collector.svg?branch=master)](https://travis-ci.org/aragilar/pytest_info_collector)
[![Coverage Status](https://codecov.io/github/aragilar/pytest_info_collector/coverage.svg?branch=master)](https://codecov.io/github/aragilar/pytest_info_collector?branch=master)
[![Version](https://img.shields.io/pypi/v/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![License](https://img.shields.io/pypi/l/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![Wheel](https://img.shields.io/pypi/wheel/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![Format](https://img.shields.io/pypi/format/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![Supported versions](https://img.shields.io/pypi/pyversions/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![Supported implemntations](https://img.shields.io/pypi/implementation/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)
[![PyPI](https://img.shields.io/pypi/status/pytest_info_collector.svg)](https://pypi.python.org/pypi/pytest_info_collector/)


pytest_info_collector is 

Bug reports and suggestions should be filed at
[https://github.com/aragilar/pytest_info_collector/issues](https://github.com/aragilar/pytest_info_collector/issues).
